==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/admin/messages/nn-NO/information.php <==
<?php

return [
    'Settings' => 'Innstillinger',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    '<strong>CronJob</strong> Status' => '',
    '<strong>Queue</strong> Status' => '',
    'About HumHub' => '',
    'Assets' => '',
    'Background Jobs' => '',
    'Base URL' => '',
    'Checking HumHub software prerequisites.' => '',
    'Configuration File' => '',
    'Current limit is: {currentLimit}' => '',
    'Custom Modules ({modules})' => '',
    'Database' => '',
    'Database collation' => '',
    'Database driver - {driver}' => '',
    'Database migration results:' => '',
    'Delayed' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'Displaying {count} entries per page.' => '',
    'Done' => '',
    'Driver' => '',
    'Dynamic Config' => '',
    'Error' => '',
    'Flush entries' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'HumHub is currently in debug mode. Disable it when running on production!' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Info' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Last run (daily):' => '',
    'Last run (hourly):' => '',
    'Licences' => '',
    'Logging' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'Never' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Optional' => '',
    'Other' => '',
    'Outstanding database migrations:' => '',
    'Permissions' => '',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => '',
    'Prerequisites' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Queue successfully cleared.' => '',
    'Re-Run tests' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Reserved' => '',
    'Runtime' => '',
    'Search index rebuild in progress.' => '',
    'Search term...' => '',
    'See installation manual for more details.' => '',
    'Select category..' => '',
    'Select day' => '',
    'Select level...' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The current main HumHub database name is ' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'There is a new update available! (Latest version: %version%)' => '',
    'This HumHub installation is up to date!' => '',
    'Total {count} entries found.' => '',
    'Trace' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Waiting' => '',
    'Warning' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/admin/messages/nn-NO/information.php <==
<?php

return [
    'Settings' => 'Innstillinger',
    '"Push Notifications (Firebase)" module and setup of Firebase API Key required' => '',
    '<strong>CronJob</strong> Status' => '',
    '<strong>Queue</strong> Status' => '',
    'About HumHub' => '',
    'Assets' => '',
    'Background Jobs' => '',
    'Base URL' => '',
    'Checking HumHub software prerequisites.' => '',
    'Configuration File' => '',
    'Current limit is: {currentLimit}' => '',
    'Custom Modules ({modules})' => '',
    'Database' => '',
    'Database collation' => '',
    'Database driver - {driver}' => '',
    'Database migration results:' => '',
    'Delayed' => '',
    'Deprecated Modules ({modules})' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Different table collations in the tables: {tables}' => '',
    'Disabled Functions' => '',
    'Displaying {count} entries per page.' => '',
    'Done' => '',
    'Driver' => '',
    'Enable <a href="{url}">Link Redirection Service</a>' => '',
    'Error' => '',
    'Flush entries' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'HumHub is currently in debug mode. Disable it when running on production!' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Info' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for Mercure push live driver' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Last run (daily):' => '',
    'Last run (hourly):' => '',
    'Licences' => '',
    'Logging' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Mobile App - Push Service' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Must be updated manually. Check compatibility with newer HumHub versions before updating.' => '',
    'Never' => '',
    'New migrations should be applied: {migrations}' => '',
    'No pending migrations' => '',
    'Optional' => '',
    'Other' => '',
    'Outstanding database migrations:' => '',
    'Permissions' => '',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => '',
    'Prerequisites' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Queue successfully cleared.' => '',
    'Re-Run tests' => '',
    'Rebuild search index' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Refresh' => '',
    'Reserved' => '',
    'Runtime' => '',
    'Search index rebuild in progress.' => '',
    'Search term...' => '',
    'See installation manual for more details.' => '',
    'Select category..' => '',
    'Select day' => '',
    'Select level...' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'The configuration file contains legacy settings. Invalid options: {options}' => '',
    'The current main HumHub database name is ' => '',
    'The module(s) are no longer maintained and should be uninstalled.' => '',
    'There is a new update available! (Latest version: %version%)' => '',
    'This HumHub installation is up to date!' => '',
    'Total {count} entries found.' => '',
    'Trace' => '',
    'Update Database' => '',
    'Uploads' => '',
    'Uploads - File' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    'Waiting' => '',
    'Warning' => '',
    'Web Application PHP version: `{webPhpVersion}`, Cron PHP Version: `{cronPhpVersion}`' => '',
    'Web Application and Cron uses the same PHP version' => '',
    'Web Application and Cron uses the same user' => '',
    'Web Application user: `{webUser}`, Cron user: `{cronUser}`' => '',
    'Your database is <b>up-to-date</b>.' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];
